==> org.apache.felix.http.base-4.2.14-source-release.zip: org.apache.felix.http.base-4.2.14/src/main/java/org/apache/felix/http/base/internal/AbstractActivator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.felix.http.base.internal;

import org.apache.felix.http.base.internal.logger.SystemLogger;
import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

public abstract class AbstractActivator
    implements BundleActivator
{
    private volatile BundleContext context;

    protected final BundleContext getBundleContext()
    {
        return this.context;
    }

    @Override
    public final void start(final BundleContext context)
        throws Exception
    {
        this.context = context;
        SystemLogger.init(context);
        doStart();
    }

    @Override
    public final void stop(final BundleContext context)
        throws Exception
    {
        doStop();
        SystemLogger.destroy();
    }

    protected abstract void doStart()
        throws Exception;

    protected abstract void doStop()
        throws Exception;
}

==> org.apache.felix.http.base-5.1.16-source-release.zip: org.apache.felix.http.base-5.1.16/src/main/java/org/apache/felix/http/base/internal/AbstractActivator.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.felix.http.base.internal;

import org.osgi.framework.BundleActivator;
import org.osgi.framework.BundleContext;

public abstract class AbstractActivator
    implements BundleActivator {

    private volatile BundleContext context;

    protected final BundleContext getBundleContext() {
        return this.context;
    }

    @Override
    public final void start(final BundleContext context)
        throws Exception {
        this.context = context;
        doStart();
    }

    @Override
    public final void stop(final BundleContext context)
        throws Exception {
        doStop();
    }

    protected abstract void doStart()
        throws Exception;

    protected abstract void doStop()
        throws Exception;
}
